@@ -43,8 +43,9 @@ from pathlib      import Path
 from os           import environ
 from typing       import Union
 
-from flags        import Flags
-from pyTerminalUI import ILineTerminal
+from flags                      import Flags
+from pyCommonClasses.Version    import Version
+from pyTerminalUI               import ILineTerminal
 
 from pyVersioning.AppVeyor      import AppVeyor
 from pyVersioning.CIService     import WorkStation
@@ -54,43 +55,6 @@ from pyVersioning.GitHub        import GitHub
 from pyVersioning.Travis        import Travis
 
 
-@dataclass
-class Version():
-	flags : int
-	major : int
-	minor : int
-	patch : int
-
-	def __init__(self, major, minor=-1, patch=-1):
-		if isinstance(major, str):
-			if major.startswith(("V", "v", "I", "i", "R", "r")):
-				major = major[1:]
-			elif major.startswith(("rev", "REV")):
-				major = major[3:]
-
-			split = major.split(".")
-			self.major = int(split[0])
-			self.minor = int(split[1])
-			self.patch = int(split[2])
-			self.flags = 0
-		elif major is None:
-			self.major = 0
-			self.minor = 0
-			self.patch = 0
-			self.flags = 0
-		else:
-			self.major = major
-			self.minor = minor
-			self.patch = patch
-			self.flags = 0
-
-	def __str__(self):
-		return "v{0}.{1}.{2}".format(self.major, self.minor, self.patch)
-
-	def __repr__(self):
-		return "{0}.{1}.{2}".format(self.major, self.minor, self.patch)
-
-
 @dataclass
 class Tool():
 	name    : str
@@ -112,6 +76,8 @@ class Git():
 	repository  : str = ""
 
 	def __post_init__(self):
+		"""Calculate `reference` from `tag` or `branch`."""
+
 		if self.tag != "":
 			self.reference = self.tag
 		elif self.branch != "":
@@ -124,11 +90,21 @@ class Git():
 class Project():
 	name    : str
 	variant : str
+	version : Version
+
+	def __init__(self, name : str, variant : str = "", version : Union[str, Version] = ""):
+		"""Assign fields and convert version string to a `Version` object."""
 
-	def __init__(self, name : str, variant : str = ""):
 		self.name    = name    if name    is not None else ""
 		self.variant = variant if variant is not None else ""
 
+		if isinstance(version, Version):
+			self.version = version
+		elif isinstance(version, str):
+			self.version = Version(version)
+		elif version is None:
+			self.version = Version(0, 0, 0)
+
 
 @dataclass
 class Compiler():
@@ -138,6 +114,8 @@ class Compiler():
 	options       : str
 
 	def __init__(self, name : str, version : Union[str, Version] = "", configuration : str = "", options : str = ""):
+		"""Assign fields and convert version string to a `Version` object."""
+
 		self.name          = name          if name          is not None else ""
 		self.configuration = configuration if configuration is not None else ""
 		self.options       = options       if options       is not None else ""
@@ -185,10 +163,15 @@ class Versioning(ILineTerminal):
 			self.platform = Platforms.Workstation
 
 	def loadDataFromConfiguration(self, config : Configuration):
+		"""Preload versioning information from configuration file."""
+
 		self.variables['project'] = self.getProject(config.project)
 		self.variables['build']   = self.getBuild(config.build)
+		self.variables['version'] = self.getVersion(config.project)
 
 	def collectData(self):
+		"""Collect versioning information from environment including CI services (if available)."""
+
 		if self.platform is Platforms.AppVeyor:
 			self.service                = AppVeyor()
 			self.variables['appveyor']  = self.service.getEnvironment()
@@ -204,14 +187,22 @@ class Versioning(ILineTerminal):
 		else:
 			self.service                = WorkStation()
 
-		self.variables['tool']     = Tool("pyVersioning", Version(0,7,0)),
-		self.variables['version']  = self.getVersion()
+		self.variables['tool']     = Tool("pyVersioning", Version(0,7,1)),
 		self.variables['git']      = self.getGitInformation()
 		self.variables['env']      = self.getEnvironment()
 		self.variables['platform'] = self.service.getPlatform()
 
-	def getVersion(self) -> Version:
-		return Version("0.0.0")
+		self.calculateData()
+
+	def calculateData(self):
+		if self.variables['git'].tag != "":
+			pass
+
+	def getVersion(self, config : Configuration.Project) -> Version:
+		if config.version is not None:
+			return config.version
+		else:
+			return Version("0.0.0")
 
 	def getGitInformation(self):
 		return Git(
@@ -332,7 +323,8 @@ class Versioning(ILineTerminal):
 	def getProject(self, config : Configuration.Project):
 		return Project(
 			name=config.name,
-			variant=config.variant
+			variant=config.variant,
+			version=config.version
 		)
 
 	def getBuild(self, config : Configuration.Build):
